@@ -12,11 +12,12 @@ use crate::{
     router::SenderPair,
     Cancel, NodeMessage, ShutdownType,
 };
+use crate::{NodeError, Reason};
 use core::time::Duration;
 use ockam_core::compat::{boxed::Box, string::String, sync::Arc, vec::Vec};
 use ockam_core::{
-    AccessControl, Address, AddressSet, LocalMessage, Message, Passthrough, Processor, Result,
-    Route, TransportMessage, Worker,
+    AccessControl, Address, AddressSet, AsyncTryClone, LocalMessage, Message, Passthrough,
+    Processor, Result, Route, TransportMessage, Worker,
 };
 
 /// A default timeout in seconds
@@ -45,6 +46,13 @@ pub struct Context {
     access_control: Box<dyn AccessControl>,
 }
 
+#[ockam_core::async_trait]
+impl AsyncTryClone for Context {
+    async fn async_try_clone(&self) -> Result<Self> {
+        self.new_context(Address::random(0)).await
+    }
+}
+
 impl Context {
     /// Return runtime clone
     pub fn runtime(&self) -> Arc<Runtime> {
@@ -322,6 +330,24 @@ impl Context {
             .map(|_| ())?)
     }
 
+    /// Send a message to another address associated with this worker
+    ///
+    /// This function is a simple wrapper around `Self::send()` which
+    /// validates the address given to it and will reject invalid
+    /// addresses.
+    pub async fn send_to_self<A, M>(&self, from: A, addr: A, msg: M) -> Result<()>
+    where
+        A: Into<Address>,
+        M: Message + Send + 'static,
+    {
+        let addr = addr.into();
+        if self.address.contains(&addr) {
+            self.send_from_address(addr, msg, from.into()).await
+        } else {
+            Err(NodeError::Rejected(Reason::InvalidAddress).into())
+        }
+    }
+
     /// Send a message via a fully qualified route
     ///
     /// Routes can be constructed from a set of [`Address`]es, or via
